package cn.com.infosec.asn1.cmp;

import cn.com.infosec.asn1.ASN1Encodable;
import cn.com.infosec.asn1.ASN1EncodableVector;
import cn.com.infosec.asn1.ASN1OctetString;
import cn.com.infosec.asn1.ASN1Sequence;
import cn.com.infosec.asn1.DEREncodable;
import cn.com.infosec.asn1.DERInteger;
import cn.com.infosec.asn1.DERObject;
import cn.com.infosec.asn1.DERSequence;

public class CertResponse extends ASN1Encodable {
   private DERInteger certReqId;
   private PKIStatusInfo status;
   private CertifiedKeyPair certifiedKeyPair;
   private ASN1OctetString rspInfo;

   private CertResponse(ASN1Sequence seq) {
      this.certReqId = DERInteger.getInstance(seq.getObjectAt(0));
      this.status = PKIStatusInfo.getInstance(seq.getObjectAt(1));
      if (seq.size() >= 3) {
         if (seq.size() == 3) {
            DEREncodable seq1;
            if ((seq1 = seq.getObjectAt(2)) instanceof ASN1OctetString) {
               this.rspInfo = ASN1OctetString.getInstance(seq1);
            } else {
               this.certifiedKeyPair = CertifiedKeyPair.getInstance(seq1);
            }
         } else {
            this.certifiedKeyPair = CertifiedKeyPair.getInstance(seq.getObjectAt(2));
            this.rspInfo = ASN1OctetString.getInstance(seq.getObjectAt(3));
         }
      }

   }

   public static CertResponse getInstance(Object o) {
      if (o instanceof CertResponse) {
         return (CertResponse)o;
      } else if (o instanceof ASN1Sequence) {
         return new CertResponse((ASN1Sequence)o);
      } else {
         throw new IllegalArgumentException("Invalid object: " + o.getClass().getName());
      }
   }

   public DERInteger getCertReqId() {
      return this.certReqId;
   }

   public PKIStatusInfo getStatus() {
      return this.status;
   }

   public CertifiedKeyPair getCertifiedKeyPair() {
      return this.certifiedKeyPair;
   }

   public DERObject toASN1Object() {
      ASN1EncodableVector var1;
      ASN1EncodableVector var10001 = var1 = new ASN1EncodableVector;
      var1.<init>();
      var1.add(this.certReqId);
      var10001.add(this.status);
      CertifiedKeyPair var2;
      if ((var2 = this.certifiedKeyPair) != null) {
         var1.add(var2);
      }

      ASN1OctetString var3;
      if ((var3 = this.rspInfo) != null) {
         var1.add(var3);
      }

      return new DERSequence(var1);
   }
}
